import React, { useState } from 'react';
import { View, TextInput, FlatList, Text, TouchableOpacity, StyleSheet } from 'react-native';
import countries from 'world-countries';
import Fuse from 'fuse.js';
import countryCodeEmoji from 'country-code-emoji';
export const CountrySelector = ({
  onSelect
}) => {
  const [searchTerm, setSearchTerm] = useState('');
  const fuse = new Fuse(countries, {
    keys: ['name.common']
  });
  const filteredCountries = fuse.search(searchTerm).map(result => result.item);
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, /*#__PURE__*/React.createElement(TextInput, {
    placeholder: "Search Country...",
    value: searchTerm,
    onChangeText: setSearchTerm,
    style: styles.textinput
  }), /*#__PURE__*/React.createElement(FlatList, {
    data: filteredCountries,
    renderItem: ({
      item
    }) => /*#__PURE__*/React.createElement(TouchableOpacity, {
      onPress: () => onSelect(item)
    }, /*#__PURE__*/React.createElement(View, {
      style: styles.row
    }, [item.cca2].map(countryCodeEmoji), /*#__PURE__*/React.createElement(Text, {
      style: styles.title
    }, item.idd.root + (item.idd.suffixes.length === 1 ? item.idd.suffixes[0] : '') + ' ' + item.name.common))),
    keyExtractor: item => item.cca2
  }));
};
const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  title: {
    marginLeft: 10
  },
  textinput: {
    borderWidth: 1,
    borderRadius: 4,
    paddingHorizontal: 8,
    paddingVertical: 4
  },
  row: {
    flexDirection: 'row',
    alignItems: 'center',
    padding: 10
  },
  box: {
    width: 60,
    height: 60,
    marginVertical: 20
  }
});
//# sourceMappingURL=index.js.map